@@ -942,7 +942,7 @@ main (int    argc,
         "flatpak",
         "build",
         "--die-with-parent",
-        "--nofilesystem=host",
+        "--nofilesystem=host:reset",
         fs_app_dir,
         fs_cache,
         "--share=network",
