@@ -68,6 +68,10 @@ GQuark builder_curl_error_quark (void);
 GQuark builder_yaml_parse_error_quark (void);
 #define BUILDER_YAML_PARSE_ERROR (builder_yaml_parse_error_quark ())
 
+JsonNode * builder_json_node_from_data (const char *relpath,
+                                        const char *contents,
+                                        GError    **error);
+
 GObject * builder_gobject_from_data (GType       gtype,
                                      const char *relpath,
                                      const char *contents,
@@ -77,12 +81,14 @@ gboolean builder_host_spawnv (GFile                *dir,
                               char                **output,
                               GSubprocessFlags      flags,
                               GError              **error,
-                              const gchar * const  *argv);
+                              const gchar * const  *argv,
+                              const gchar * const  *unresolved_argv);
 gboolean builder_maybe_host_spawnv (GFile                *dir,
                                     char                **output,
                                     GSubprocessFlags      flags,
                                     GError              **error,
-                                    const gchar * const  *argv);
+                                    const gchar * const  *argv,
+                                    const gchar * const  *unresolved_argv);
 
 gboolean builder_download_uri (SoupURI        *uri,
                                GFile          *dest,
